// Code generated by tygo. DO NOT EDIT.
import * as MautrixID from "../id/index.ts"
import * as MautrixBridgeV2 from "../bridgev2/index.ts"
import * as MautrixEvent from "../event/index.ts"
import * as MautrixBridgeV2Commands from "../bridgev2/commands/index.ts"
import * as MautrixBridgeV2NetworkID from "../bridgev2/networkid/index.ts"
import * as MautrixBridgeStatus from "../bridge/status/index.ts"
import * as BeeperSDKBridgesTypes from "../../../../github.com/beeper/beeper-client-sdk/pkg/bridges/types/index.ts"
//////////
// source: contenturi.go

/**
 * ContentURIString is a string that's expected to be a Matrix content URI.
 * It's useful for delaying the parsing of the content URI to move errors from the event content
 * JSON parsing step to a later step where more appropriate errors can be produced.
 */
export type ContentURIString = string;
/**
 * ContentURI represents a Matrix content URI.
 * https://spec.matrix.org/v1.2/client-server-api/#matrix-content-mxc-uris
 */
export interface ContentURI {
  Homeserver: string;
  FileID: string;
}

//////////
// source: crypto.go

/**
 * OlmMsgType is an Olm message type
 */
export type OlmMsgType = number /* int */;
export const OlmMsgTypePreKey: OlmMsgType = 0;
export const OlmMsgTypeMsg: OlmMsgType = 1;
/**
 * Algorithm is a Matrix message encryption algorithm.
 * https://spec.matrix.org/v1.2/client-server-api/#messaging-algorithm-names
 */
export type Algorithm = string;
export const AlgorithmOlmV1: Algorithm = "m.olm.v1.curve25519-aes-sha2";
export const AlgorithmMegolmV1: Algorithm = "m.megolm.v1.aes-sha2";
export type KeyAlgorithm = string;
export const KeyAlgorithmCurve25519: KeyAlgorithm = "curve25519";
export const KeyAlgorithmEd25519: KeyAlgorithm = "ed25519";
export const KeyAlgorithmSignedCurve25519: KeyAlgorithm = "signed_curve25519";
export type CrossSigningUsage = string;
export const XSUsageMaster: CrossSigningUsage = "master";
export const XSUsageSelfSigning: CrossSigningUsage = "self_signing";
export const XSUsageUserSigning: CrossSigningUsage = "user_signing";
export type KeyBackupAlgorithm = string;
export const KeyBackupAlgorithmMegolmBackupV1: KeyBackupAlgorithm = "m.megolm_backup.v1.curve25519-aes-sha2";
/**
 * BackupVersion is an arbitrary string that identifies a server side key backup.
 */
export type KeyBackupVersion = string;
/**
 * A SessionID is an arbitrary string that identifies an Olm or Megolm session.
 */
export type SessionID = string;
/**
 * Ed25519 is the base64 representation of an Ed25519 public key
 */
export type Ed25519 = string;
export type SigningKey = Ed25519;
/**
 * Curve25519 is the base64 representation of an Curve25519 public key
 */
export type Curve25519 = string;
export type SenderKey = Curve25519;
export type IdentityKey = Curve25519;
/**
 * A DeviceID is an arbitrary string that references a specific device.
 */
export type DeviceID = string;
/**
 * A DeviceKeyID is a string formatted as <algorithm>:<device_id> that is used as the key in deviceid-key mappings.
 */
export type DeviceKeyID = string;
/**
 * A KeyID a string formatted as <keyalgorithm>:<key_id> that is used as the key in one-time-key mappings.
 */
export type KeyID = string;
/**
 * Device contains the identity details of a device and some additional info.
 */
export interface Device {
  UserID: UserID;
  DeviceID: DeviceID;
  IdentityKey: Curve25519;
  SigningKey: Ed25519;
  Trust: TrustState;
  Deleted: boolean;
  Name: string;
}
export interface CrossSigningKey {
  Key: Ed25519;
  First: Ed25519;
}
/**
 * Secret storage keys
 */
export type Secret = string;
export const SecretXSMaster: Secret = "m.cross_signing.master";
export const SecretXSSelfSigning: Secret = "m.cross_signing.self_signing";
export const SecretXSUserSigning: Secret = "m.cross_signing.user_signing";
export const SecretMegolmBackupV1: Secret = "m.megolm_backup.v1";
/**
 * VerificationTransactionID is a unique identifier for a verification
 * transaction.
 */
export type VerificationTransactionID = string;

//////////
// source: matrixuri.go

/**
 * MatrixURI contains the result of parsing a matrix: URI using ParseMatrixURI
 */
export interface MatrixURI {
  Sigil1: number /* rune */;
  Sigil2: number /* rune */;
  MXID1: string;
  MXID2: string;
  Via: string[];
  Action: string;
}

//////////
// source: opaque.go

/**
 * A RoomID is a string starting with ! that references a specific room.
 * https://matrix.org/docs/spec/appendices#room-ids-and-event-ids
 */
export type RoomID = string;
/**
 * A RoomAlias is a string starting with # that can be resolved into.
 * https://matrix.org/docs/spec/appendices#room-aliases
 */
export type RoomAlias = string;
/**
 * An EventID is a string starting with $ that references a specific event.
 * https://matrix.org/docs/spec/appendices#room-ids-and-event-ids
 * https://matrix.org/docs/spec/rooms/v4#event-ids
 */
export type EventID = string;
/**
 * A BatchID is a string identifying a batch of events being backfilled to a room.
 * https://github.com/matrix-org/matrix-doc/pull/2716
 */
export type BatchID = string;

//////////
// source: trust.go

/**
 * TrustState determines how trusted a device is.
 */
export type TrustState = number /* int */;
export const TrustStateBlacklisted: TrustState = -100;
export const TrustStateUnset: TrustState = 0;
export const TrustStateUnknownDevice: TrustState = 10;
export const TrustStateForwarded: TrustState = 20;
export const TrustStateCrossSignedUntrusted: TrustState = 50;
export const TrustStateCrossSignedTOFU: TrustState = 100;
export const TrustStateCrossSignedVerified: TrustState = 200;
export const TrustStateVerified: TrustState = 300;
export const TrustStateInvalid: TrustState = (1 << 31) - 1;

//////////
// source: userid.go

/**
 * UserID represents a Matrix user ID.
 * https://matrix.org/docs/spec/appendices#user-identifiers
 */
export type UserID = string;
export const UserIDMaxLength = 255;
